<?php 
	require_once "conexion.php";
	class ModeloPerfil extends ModeloConexion{
		
		/*=============================================================================
		ACTUALIZA PERFIL
		==============================================================================*/
		protected function mdlActualizaPerfil($id_perfil, $descripcion_perfil, $estado_perfil){


			$query = "UPDATE sie_perfiles SET descripcion = '$descripcion_perfil', estado = '$estado_perfil' WHERE id = '$id_perfil'";

			$sql = ModeloConexion::conectardb()->prepare($query);

			$sql->execute();

			return $sql;

		}

		/*=============================================================================
		CONSUTA PERFILES
		==============================================================================*/
		protected function mdlConsultaPerfiles(){

			$query = "SELECT * FROM sie_perfiles ORDER BY descripcion ASC";

			$sql = ModeloConexion::conectardb()->prepare($query);

			$sql->execute();

			return $sql;

		}

		/*=============================================================================
		CONSUTA PERFIL
		==============================================================================*/
		protected function mdlConsultaPerfildsc($descipcion_perfil){

			$query = "SELECT * FROM sie_perfiles WHERE descripcion = '$descipcion_perfil'";

			$sql = ModeloConexion::conectardb()->prepare($query);

			$sql->execute();

			return $sql;

		}


		

		/*=============================================================================
		CONSUTA PERFILES
		==============================================================================*/
		protected function mdlConsultaPerfil($id){

			$query = "SELECT * FROM sie_perfiles WHERE id = '$id' ORDER BY descripcion ASC";

			$sql = ModeloConexion::conectardb()->prepare($query);

			$sql->execute();

			return $sql;

		}

		/*=============================================================================
		CONSUTA PERFILES
		==============================================================================*/
		protected function mdlUsuario($id_perfil){

			$query = "SELECT * FROM sie_usuarios WHERE id_perfil = '$id_perfil' AND estado = 1 ORDER BY nombres ASC";

			$sql = ModeloConexion::conectardb()->prepare($query);

			$sql->execute();

			return $sql;

		}

		/*=============================================================================
		REGISTRA PERFIL
		==============================================================================*/
		protected function mdlRegistraPerfil($datos){

			$query = "INSERT INTO sie_perfiles(descripcion, estado, fecha_creacion, id_usuario_crea)VALUES(:descripcion, :estado, :fecha_creacion, :id_usuario_crea)";

			$sql = ModeloConexion::conectardb()->prepare($query);

			$sql->bindParam(':descripcion', $datos['descripcion_perfil']);
			$sql->bindParam(':estado', $datos['estado_perfil']);
			$sql->bindParam(':id_usuario_crea', $datos['id_usuario']);
			$sql->bindParam(':fecha_creacion', $datos['fecha']);

			$sql->execute();

			return $sql;

		}

		/*=============================================================================
		CONSULTA PROCESOS
		==============================================================================*/
		protected function mdlConsultaProcesos(){

			$query = "SELECT * FROM sie_procesos";

			$sql = ModeloConexion::conectardb()->prepare($query);

			$sql->execute();

			return $sql;

		}		

		
		/*=============================================================================
		CONSULTA ULTIMO PERFIL REGISTRADO
		==============================================================================*/
		protected function mdlConsultaUltimoPerfilRegistrado(){

			$query = "SELECT MAX(id) AS ultimo_perfil_registrado FROM sie_perfiles";

			$sql = ModeloConexion::conectardb()->prepare($query);

			$sql->execute();

			return $sql;

		}			

		/*=============================================================================
		REGISTRA SIE_PERMISOS
		==============================================================================*/
		protected function mdlRegistraSiePermisos($datos){

			$query = "INSERT INTO sie_permisos (id_perfil, id_proceso, activo, fecha_concedido, id_usuario_concede, fecha_denegado, id_usuario_deniega)VALUES(:id_perfil, :id_proceso, :activo, :fecha_concedido, :id_usuario_concede, :fecha_denegado, :id_usuario_deniega)";

			$sql = ModeloConexion::conectardb()->prepare($query);

			$sql->bindParam(':id_perfil', $datos['id_perfil']);
			$sql->bindParam(':id_proceso', $datos['id_proceso']);
			$sql->bindParam(':activo', $datos['activo']);
			$sql->bindParam(':fecha_concedido', $datos['fecha_concedido']);
			$sql->bindParam(':id_usuario_concede', $datos['id_usuario_concede']);
			$sql->bindParam(':fecha_denegado', $datos['fecha_denegado']);
			$sql->bindParam(':id_usuario_deniega', $datos['id_usuario_deniega']);

			$sql->execute();

			return $sql;

		}		

	}

 ?>